package com.uncontrol.shifter {
	import com.uncontrol.BoilerPlate;
 	import flash.events.Event;
	import flash.display.Sprite;
	
	import flash.display.Shape;
	import flash.display.LineScaleMode;
	import flash.display.CapsStyle;
	import flash.display.JointStyle;

	public class View extends BoilerPlate {

		private var view:Sprite;
		private var count;

		private var lineColor:Number = 0x000000;
		private var lineAlpha:Number = .5;
		private var lineWidth:Number = 1;
		
		public function View():void {
			setScope('View');
		}
		
		public function clear():void{
			view.graphics.clear();
		}
		
		public function drawStaticShapeWithArray(point:Array=null,isClosed:Boolean=false):void{
			view.graphics.lineStyle(getLineWidth(), getLineColor(), getLineAlpha(), false, LineScaleMode.NORMAL, CapsStyle.ROUND, JointStyle.MITER, 10);
			view.graphics.moveTo(point[0].x, point[0].y); 		// pointA offset
			for(var i:int=0; i<point.length; i++){
				view.graphics.lineTo(point[i].x, point[i].y); 	// actually drawing
			}
			if(isClosed){
				view.graphics.lineTo(point[0].x, point[0].y);	// closed loop if true	
			}
		}
		
		public function drawStaticShapeWithArrayFill(point:Array=null):void{
			// view.graphics.lineStyle(getLineWidth(), getLineColor(), getLineAlpha(), false, LineScaleMode.NORMAL, CapsStyle.ROUND, JointStyle.MITER, 10);
			view.graphics.beginFill(getLineColor(), getLineAlpha());
			
			view.graphics.moveTo(point[0].x, point[0].y); 		// pointA offset
			for(var i:int=0; i<point.length; i++){
				view.graphics.lineTo(point[i].x, point[i].y); 	// actually drawing
			}
			view.graphics.lineTo(point[0].x, point[0].y);	// closed loop if true	
			view.graphics.endFill();
		}

		public function drawActiveShapeWithArray(point:Array=null,parentCount:int=0,tailPercentage:Number=.5,isfaded:Boolean=true,isLooped:Boolean=false):void{
			
			var i:int;
			var pointA:int;
			var pointB:int;
			var tailLength:Number;
			var tailPercentage:Number;
			
			// fixes for looping
			parentCount += point.length;
			parentCount = parentCount%point.length;
			
			// determines tail length based on array length
			tailPercentage 	= (tailPercentage>=1 || tailPercentage<=0) ? .5 : tailPercentage;
			tailLength 		= Math.round(point.length*Math.abs(tailPercentage));

			// pointA is the back , pointB is the front
			pointA 	= parentCount-tailLength;
			pointB 	= parentCount;
		
			// draws secondary line when split
			if(pointA<0){
				var tempPointA = point.length-tailLength+parentCount;
				var tempPointB = point.length;
				view.graphics.moveTo(point[tempPointA].x, point[tempPointA].y); 	// pointA offset
				for(i=tempPointA; i<tempPointB; i++){
					if(isfaded){
						view.graphics.lineStyle(getLineWidth(), fadeHex(0xFFFFFF,getLineColor(),(i-tempPointA)/tailLength), 1, false, LineScaleMode.NORMAL, CapsStyle.ROUND, JointStyle.MITER, 10);
					}
					view.graphics.lineTo(point[i].x, point[i].y); 		// actually drawing
				}
				if(isLooped){
					if(isfaded){
						view.graphics.lineStyle(getLineWidth(), fadeHex(0xFFFFFF,getLineColor(),(i-tempPointA)/tailLength), 1, false, LineScaleMode.NORMAL, CapsStyle.ROUND, JointStyle.MITER, 10);
					}
					view.graphics.lineTo(point[0].x, point[0].y); 		// actually drawing
				}
			}
			// draws standard line
			if(pointB<(point.length+tailLength)){
				if(pointA<0){					
					pointA = 0;					
				}
				
				if(pointB>point.length){		
					pointB = point.length;		
				}

				view.graphics.moveTo(point[pointA].x, point[pointA].y); 	// pointA offset
				for(i=pointA; i<pointB; i++){
					if(isfaded){
						view.graphics.lineStyle(getLineWidth(), fadeHex(0xFFFFFF,getLineColor(),(i-(parentCount-tailLength))/tailLength), 1, false, LineScaleMode.NORMAL, CapsStyle.ROUND, JointStyle.MITER, 10);
					}
					view.graphics.lineTo(point[i].x, point[i].y); 		// actually drawing
				}
			}
		}
		
		public function fadeHex (hex, hex2, ratio){
			var r = hex >> 16;
			var g = hex >> 8 & 0xFF;
			var b = hex & 0xFF;
			r += ((hex2 >> 16)-r)*ratio;
			g += ((hex2 >> 8 & 0xFF)-g)*ratio;
			b += ((hex2 & 0xFF)-b)*ratio;
			return(r<<16 | g<<8 | b);
		}
		
		
		// -------------------------------------------------------------------------------------------
		// getter setter methods
		// -------------------------------------------------------------------------------------------
		public function setView(arg:Sprite=null):void{
			view = arg;
		}
		public function getView():Sprite{
			return view;
		}
		
		public function setLineColor(arg:Number):void{
			lineColor = arg;
		}
		public function getLineColor():Number{
			return lineColor;
		}
		public function setLineAlpha(arg:Number):void{
			lineAlpha = arg;
		}
		public function getLineAlpha():Number{
			return lineAlpha;
		}
		public function setLineWidth(arg:Number):void{
			lineWidth = arg;
		}
		public function getLineWidth():Number{
			return lineWidth;
		}

	}
}


